@@ -26,7 +26,7 @@ import sys
 import os
 
 cpwd = os.path.abspath(__file__)
-sys.path.append(os.path.dirname(cpwd+"../cFp_Zoo/HOST/vision"))
+sys.path.append(os.path.dirname(cpwd+"./cFp_Zoo/HOST/vision"))
 
 import vision
 
